DRC_VERSION = (0, 0, 8)

PATIENTS_API_VERSION = (0, 0, 8)
APPOINTMENTS_API_VERSION = (0, 0, 8)
DOCUMENTS_API_VERSION = (0, 0, 8)
MEDICATIONS_API_VERSION = (0, 0, 8)

USERS_API_VERSION = (0, 0, 8)
DOCTORS_API_VERSION = (0, 0, 8)

